#!/bin/bash

# Set up directories
APPS_DIR=~/apps
TASKAPP_DIR="$APPS_DIR/taskapp"
PROFILE_FILE=~/.profile
BACKUP_PROFILE="$PROFILE_FILE.bak"
LOG_FILE="$TASKAPP_DIR/taskapp.log"
TASKAPP_START_COMMAND="python3 \"$TASKAPP_DIR/taskapp.py\" >> \"$LOG_FILE\" 2>&1 &"
TASKAPP_START_MARKER="# <<< TaskApp Start >>>"
TASKAPP_STOP_MARKER="# <<< End TaskApp Start >>>"

# Function to create a backup of .profile
backup_profile() {
    if [ ! -f "$BACKUP_PROFILE" ]; then
        cp "$PROFILE_FILE" "$BACKUP_PROFILE"
        echo "Backup of .profile created at $BACKUP_PROFILE."
    else
        echo "Backup of .profile already exists at $BACKUP_PROFILE."
    fi
}

# Function to append TaskApp start command to .profile
append_to_profile() {
    echo "" >> "$PROFILE_FILE"
    echo "$TASKAPP_START_MARKER" >> "$PROFILE_FILE"
    echo "$TASKAPP_START_COMMAND" >> "$PROFILE_FILE"
    echo "$TASKAPP_STOP_MARKER" >> "$PROFILE_FILE"
    echo "Added TaskApp start command to $PROFILE_FILE."
}

# Create Apps directory if it doesn't exist
mkdir -p "$APPS_DIR"

# Download and install Python
echo "Downloading Python package..."
curl -O https://berrystore.sw7ft.com/python/python3.11/python3_ntoarmv7-qnx-static.zip

echo "Downloading Python installation script..."
curl -O https://berrystore.sw7ft.com/python/python3.11/install.sh

echo "Setting permissions for installation script..."
chmod +x install.sh

echo "Unzipping Python package..."
unzip -o python3_ntoarmv7-qnx-static.zip

echo "Installing Python..."
./install.sh

# Install TaskApp
echo "Downloading TaskApp..."
curl -O https://berrystore.sw7ft.com/apps/taskapp.zip

echo "Creating TaskApp directory..."
mkdir -p "$TASKAPP_DIR"

echo "Unzipping TaskApp into $TASKAPP_DIR..."
unzip -o taskapp.zip -d "$TASKAPP_DIR"

# Handle nested taskapp directory if present
if [ -d "$TASKAPP_DIR/taskapp" ]; then
    echo "Detected nested 'taskapp' directory. Moving contents to '$TASKAPP_DIR'..."
    mv "$TASKAPP_DIR/taskapp/"* "$TASKAPP_DIR/"
    rmdir "$TASKAPP_DIR/taskapp"
    echo "Moved TaskApp files to '$TASKAPP_DIR'. Removed redundant 'taskapp' directory."
fi

# Ensure taskapp.py is executable
chmod +x "$TASKAPP_DIR/taskapp.py"

# Backup .profile before making changes
echo "Backing up existing .profile..."
backup_profile

# Update .profile to run TaskApp on terminal startup
echo "Updating .profile to run TaskApp on startup..."

# Check if the start marker exists in .profile
if grep -Fq "$TASKAPP_START_MARKER" "$PROFILE_FILE"; then
    echo "TaskApp start commands already exist in $PROFILE_FILE."
else
    append_to_profile
fi

# Cleanup downloaded files
echo "Cleaning up..."
rm -f python3_ntoarmv7-qnx-static.zip taskapp.zip install.sh

echo "Installation complete. TaskApp is located in $TASKAPP_DIR."
echo "TaskApp will run automatically on terminal startup."

# Optionally, source the updated .profile to apply changes immediately
# Uncomment the line below if you want the changes to take effect immediately
# source "$PROFILE_FILE"